#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MSIX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MSIX_HPP_INCLUDED

#include <boost/simd/constant/include/constants/msix.hpp>

#endif
